use crate::guess::*;
use crate::guesser;
use crate::evaluator;

pub struct Game<'a, const N: usize> {
    pub guesser: &'a mut dyn guesser::Guesser<N>,
    pub evaluator: &'a mut dyn evaluator::Evaluator<N>,
}

impl<'a, const N: usize> Game<'a, N> {
    pub fn play_round(&mut self) -> GuessResult<N> {
        let word = self.guesser.guess();
        let matches = self.evaluator.evaluate(word);
        let result = GuessResult { word, matches };
        result
    }

    pub fn push(&mut self, result: GuessResult<N>) {
        self.guesser.push(result);
        self.evaluator.push(result);
    }
}
